@@ -198,7 +198,7 @@ static int bubblemon_getMsecsSinceLastCall()
 
   /* What time is it now? */
   gettimeofday(&currentTime, NULL);
-
+  
   if ((last_sec != 0L) || (last_usec != 0L))
   {
     returnMe = 1000 * (int)(currentTime.tv_sec - last_sec);
@@ -288,7 +288,6 @@ static void bubblemon_addNourishment(bubblemon_Weed *weed, int percentage)
 static void bubblemon_updateWeeds(int msecsSinceLastCall)
 {
   static int timeToNextUpdate = 0;
-  static int lastUpdatedWeed = 0;
 
   int w = bubblePic.width;
   int x;
@@ -298,22 +297,17 @@ static void bubblemon_updateWeeds(int msecsSinceLastCall)
   while (timeToNextUpdate <= 0)
   {
     // ... update the nourishment level of our next weed
-    lastUpdatedWeed--;
-    if ((lastUpdatedWeed <= 0) ||
-	(lastUpdatedWeed >= bubblePic.width))
-    {
-      lastUpdatedWeed = bubblePic.width - 1;
-    }
+    int weed = random() % bubblePic.width;
     
     // Distribute the nourishment over several weeds
-    if (lastUpdatedWeed > 0)
+    if (weed > 0)
     {
-      bubblemon_addNourishment(&(physics.weeds[lastUpdatedWeed - 1]), (netload_getLoadPercentage() * 8) / 10);
+      bubblemon_addNourishment(&(physics.weeds[weed - 1]), (netload_getLoadPercentage() * 8) / 10);
     }
-    bubblemon_addNourishment(&(physics.weeds[lastUpdatedWeed]), netload_getLoadPercentage());
-    if (lastUpdatedWeed < (bubblePic.width - 1))
+    bubblemon_addNourishment(&(physics.weeds[weed]), netload_getLoadPercentage());
+    if (weed < (bubblePic.width - 1))
     {
-      bubblemon_addNourishment(&(physics.weeds[lastUpdatedWeed + 1]), (netload_getLoadPercentage() * 8) / 10);
+      bubblemon_addNourishment(&(physics.weeds[weed + 1]), (netload_getLoadPercentage() * 8) / 10);
     }
     
     timeToNextUpdate += NETLOAD_INTERVAL;
@@ -1035,9 +1029,14 @@ const bubblemon_picture_t *bubblemon_getPicture()
   static const int msecsPerPhysicsFrame = 1000 / PHYSICS_FRAMERATE;
   static int physicalTimeElapsed = 0;
   
-  int msecsSinceLastCall = bubblemon_getMsecsSinceLastCall();
+  int msecsSinceLastCall;
   int youveGotMail = mail_hasUnreadMail();
   
+  // Make sure we never try to move things backwards
+  do {
+    msecsSinceLastCall = bubblemon_getMsecsSinceLastCall();
+  } while (msecsSinceLastCall < 0);
+  
   // Get the system load
   meter_getLoad(&sysload);
   bubblemon_censorLoad();
